#accordion-section-header_image {
    margin-top: 0px;
}

.customize-control-hidden {
    margin: 0 -12px;
    margin-bottom: 12px;
    display: block;
    padding: 13px 12px;
    border-width: 1px 0;
    border-style: solid;
    border-color: #dddddd;
    background-color: #fff;
    font-weight: 500;
    letter-spacing: 1px;
    line-height: 1;
    text-transform: uppercase;
	color: #3292db;
}

.customize-control-hidden label {
    margin-bottom: 0;
    line-height: 1;
    font-size: 11.5px;
    cursor: default;
}



.consultstreet-getting-started-notice {
    padding: 20px 10px;
    display: -webkit-flex;
    display: -moz-flex;
    display: -ms-flex;
    display: -o-flex;
    display: flex;
    -ms-align-items: center;
    align-items: center;
}

.consultstreet-theme-screenshot img {
    width: 100%;
    max-width: 200px;
    display: inline-block;
    vertical-align: top;
    border: 2px solid #ddd;
    border-radius: 4px;
}

.consultstreet-theme-notice-content {
    width: 70%;
    display: block;
    vertical-align: top;
    padding: 0 20px;
}

h2.consultstreet-notice-h2 {
    margin: 0 0 10px;
    font-weight: 400;
    line-height: 1.3;
}

.consultstreet-push-down {
    padding-top: 15px;
    display: inline-block;
    padding-left: 8px;
}

.consultstreet-button-padding.updating-message::before {
  margin-top: 12px;
}



/* Upsale */
.pro_info ul {
	margin: 0;
	padding: 0;
}

.pro_info ul li {
	margin-bottom: 10px;
}

.pro_info ul li a, .up-to-pro {
	font-family: 'Noto Sans', sans-serif;
    font-weight: bold;
	padding: 12px 10px;
	display: block;
	text-decoration: none;
	color: #ffffff;
	border-radius: 3px;
	    font-size: 14px;
    letter-spacing: 1px;
	overflow: hidden;
    -webkit-transition: .3s;
    transition: .3s;	
	background: #009efa;  /* fallback for old browsers */
	background: -webkit-linear-gradient(to right, #233fe7, #009efa);  /* Chrome 10-25, Safari 5.1-6 */
	background: linear-gradient(to right, #233fe7, #009efa);/* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */	
    z-index: 2;    
}
.pro_info ul li a:hover, .pro_info ul li a:focus,
.up-to-pro:hover, .up-to-pro:focus {
	transform: translateY(-3px);
    color: #fff;
    box-shadow: 0 0.5rem 1.875rem rgba(0, 0, 0, 0.15);	
}
.show-love {
    background-image: -webkit-linear-gradient( 90deg, #e4aa00 0%, #fddb3e 100%) !important;
	background: #FF512F;  /* fallback for old browsers */
	background: -webkit-linear-gradient(to right, #DD2476, #FF512F) !important;  /* Chrome 10-25, Safari 5.1-6 */
	background: linear-gradient(to right, #DD2476, #FF512F) !important; /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */	
}
.up-to-pro {
    padding: 9px 58px;
    text-transform: capitalize;
}
.pro_info ul li a i{
	font-size: 15px;
	margin-top: 1px;
	margin-right: 7px;
}
.pro_info .upgrade-to-pro, .up-to-pro{
	background: #780206;  /* fallback for old browsers */
background: -webkit-linear-gradient(to right, #061161, #780206);  /* Chrome 10-25, Safari 5.1-6 */
background: linear-gradient(to right, #061161, #780206); /* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */

}
li#accordion-section-upgrade_premium .accordion-section-title:after {
    content: "\f174" !important;
    color: #ffffff !important;
}
li#accordion-section-upgrade_premium .accordion-section-title,
li#accordion-section-upgrade_premium .accordion-section-title:hover {
	color: #ffffff !important;
	border-left: none;
	background: #009efa;  /* fallback for old browsers */
	background: -webkit-linear-gradient(to right, #233fe7, #009efa) !important;  /* Chrome 10-25, Safari 5.1-6 */
	background: linear-gradient(to right, #233fe7, #009efa) !important;/* W3C, IE 10+/ Edge, Firefox 16+, Chrome 26+, Opera 12+, Safari 7+ */
}
#customize-controls .control-section .accordion-section-title button:focus, #customize-controls .control-section .accordion-section-title button:hover, #customize-controls .control-section.open .accordion-section-title, #customize-controls .control-section:hover>.accordion-section-title {
    color: unset;
    background: unset;
}
/*customizer Setting*/
.updated.notice-get-started-class {
	background-color: #ffffff;
} 
.notice.notice-success {
	background-color: #FFFFFF;
}
.notice-success .notice-text{ font-size : 17px;}