/*
Name: bootstrap-smartmenus.css
*/

/* Carets in collapsible mode (make them look like +/- buttons) */

.navbar { 
	background-color: transparent;
	padding-top: 1rem;
	padding-bottom: 1rem;
	padding-left: 0rem;
	padding-right: 0rem;
	opacity: 1;
	box-shadow: 0 1px 2px rgba(0,0,0,.05);
	z-index: 2;
}
.m-right-auto {
    margin-right: unset!important;
    margin-left: auto;
}
.navbar>.container {
    display: block;
}


/*--------------------------------------------------
=>> Site Branding Text & Navar Brand
--------------------------------------------------*/

.navbar-brand {
    padding-top: 0.375rem;
    padding-bottom: 0.375rem;
}
.navbar-brand, .sticky-navbar-brand {
    float: left;
}
.site-branding-text {
	margin-right: 1rem;
	display: inline-block;
}
.site-branding-text .site-title {
    font-size: 1.6rem;
    line-height: inherit;
    white-space: normal;
    line-height: 1.2;
    margin: -2px 0 0;
}
.site-branding-text .site-description {
	line-height: 1.4;
	padding-top: 0.063rem;
}
.navbar-brand .custom-logo, 
.navbar.header-fixed-top .sticky-navbar-brand .custom-logo { 
	max-width: 100%;
	display: block;
	height: auto;
}
.navbar.navbar-header-wrap.header-fixed-top .site-branding-text .site-title a {
    color: #000;
}
.navbar.navbar-header-wrap.header-fixed-top .site-branding-text .site-description {
    color: #404040;
}
.navbar .row.align-self-center {
    margin-left: 0;
    margin-right: 0;
}

/*Toggle Button*/
.navbar .navbar-toggler {
	float: right;
	margin-top: 0.238rem;
	border-color: unset;	
	padding-left: 0;
	padding-right: 0;
	color: transparent;
}
.navbar.navbar-header-wrap .navbar-toggler {
    border-color: rgba(255, 255, 255, 1);
}
.navbar.navbar-header-wrap.header-fixed-top .navbar-toggler {
    border-color: rgba(0, 0, 0, 0.1);
}
.navbar-toggler:hover, 
.navbar-toggler:focus {
	background-color: transparent;	
}  
.navbar-toggler:focus {
	outline: 1px dotted #fff;
} 
.header-fixed-top .navbar-toggler:focus {
    outline: 1px dotted #000;
}
.navbar .navbar-toggler-icon {
	background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(1, 1, 47, 0)' stroke-width='2' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
	width: 4rem;
}

/*Menu & Dropdown Css*/
.navbar .nav .menu-item {
    margin-right: 0;
}
.navbar .nav .menu-item:last-child {
    margin-right: 0px;
}
.navbar .nav .menu-item .nav-link {
    font-weight: 600;
    color: #061018;
	padding: 0;
}
.navbar .nav .dropdown-menu { 
	border-radius: 0;
	border: none;
	padding: 0.438rem 0.625rem;
	font-size: 0.938rem;
}
.navbar .nav .dropdown-item {
	padding: .30rem 0.75rem;
}  
.navbar .nav .dropdown-menu .menu-item { 
	margin-right: 0;
}
.navbar .nav .dropdown-item.active, .navbar .nav .dropdown-item:active {
    color: #fff;
    background-color: transparent;
}
a.bg-light:focus, a.bg-light:hover { 
	background-color: transparent !important;
}
.navbar .nav .dropdown-menu > .menu-item > ul.dropdown-menu > .menu-item > .dropdown-item {
    color: #000 !important;
}

/*Navbar Header Wrap*/

.navbar-header-wrap {
	background-color: rgba(0, 0, 0, .4);
	position: absolute;
	right: 0;
	left: 0;
	z-index: 2;
}
.navbar-header-wrap.not-sticky .site-branding-text .site-title a, 
.navbar-header-wrap.not-sticky .site-branding-text .site-description {
	color: #fff;
}
.navbar.navbar-header-wrap .navbar-toggler-icon {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(255, 255, 255, 1)' stroke-width='3' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
}
.navbar.navbar-header-wrap.header-fixed-top .navbar-toggler-icon {
  background-image: url("data:image/svg+xml;charset=utf8,%3Csvg viewBox='0 0 30 30' xmlns='http://www.w3.org/2000/svg'%3E%3Cpath stroke='rgba(1, 1, 47, 1)' stroke-width='3' stroke-linecap='round' stroke-miterlimit='10' d='M4 7h22M4 15h22M4 23h22'/%3E%3C/svg%3E");
}
.navbar.navbar-header-wrap .nav .menu-item .nav-link, 
.navbar.navbar-header-wrap .nav a.cart-icon, 
.navbar.navbar-header-wrap .nav .theme-search-block a {
    color: #fff;
}
.navbar.navbar-header-wrap .nav .btn-border {
	background: transparent;
	color: #ffffff;
	border: 2px solid #ffffff;
}
.navbar.navbar-header-wrap .nav .btn-border:hover, 
.navbar.navbar-header-wrap .nav .btn-border:focus, 
.navbar.navbar-header-wrap.header-fixed-top .nav .btn-border:hover, 
.navbar.navbar-header-wrap.header-fixed-top .nav .btn-border:focus {
	color: #ffffff;
}
.navbar.navbar-header-wrap.header-fixed-top .nav .menu-item .nav-link, 
.navbar.navbar-header-wrap.header-fixed-top .nav a.cart-icon, 
.navbar.navbar-header-wrap.header-fixed-top .nav .theme-search-block a {
    color: #000;
}
.navbar.navbar-header-wrap.header-fixed-top .nav .menu-item.active .nav-link {
	color: #fff;
}
.navbar.navbar-header-wrap.header-fixed-top .nav .btn-border {
	background: transparent;
	color: #000;
}

/*Header Sticky*/
.header-fixed-top {
	background-color: #fff;
	position: fixed;
	top:0; 
	left:0;
	width: 100%; 
	z-index: 3;
	box-shadow: 0 8px 20px 0 rgba(0,0,0,.1);
	opacity: 1;
	-webkit-animation: slide-down 1.07s;
	animation: slide-down 1.07s;
}
@keyframes slide-down {
    0% {
        opacity: 1;
        transform: translateY(-100%);
    } 
    100% {
        opacity: 1;
        transform: translateY(0);
    } 
}

.navbar.header-fixed-top .nav {
    margin-bottom: 0;
}
.navbar.header-fixed-top .site-branding-text {
	padding-top: 0.670rem;
    padding-bottom: 0.670rem;
}
.navbar.header-fixed-top .nav .themes-header-top {
    padding: 1rem 0;
}
.navbar.header-fixed-top .nav .menu-item .nav-link {
    padding: 1.400rem 1rem;
}
@media (max-width: 991px) {
	/*When we add more menus then show vertical scroll in mobiles*/
	.navbar-collapse{
		max-height: 400px;
		overflow-x: hidden;
	}
	.navbar .nav .menu-item {
		margin-right: 28px;
	}
	.navbar .container {
		padding-left: 15px;		
		padding-right: 15px;
	}	
	.row.align-self-center .align-self-center {
		width: 100%;
	}
	.site-branding-text {
		padding-top: 0.375rem;
		padding-bottom: 0.375rem;
	}
	.navbar.header-fixed-top .site-branding-text {
		padding-top: 0.175rem;
		padding-bottom: 0.175rem;
	}
	.navbar-brand, .sticky-navbar-brand {
		float: left;
	}
	.sticky-navbar-brand {
		margin-right: 1rem;
	}
	.navbar .nav {	
		margin-top: 1.25rem;
		margin-bottom: 1.25rem;
		margin-left: 0;
		position: relative;
	}
	.navbar .nav .menu-item {
		margin-right: 0;
	}
	.navbar .nav .menu-item .nav-link {
		line-height: 40px;
		margin-right: 2px;
		margin-left: 2px;
		display: block;
		border-bottom: 1px solid #f1f1f1;
		border-radius: 0;
		padding: 0 !important;
	}
	.navbar .nav .dropdown-item:focus, 
	.navbar .nav .dropdown-item:hover {
		background-color: transparent;
	}
	.themes-header-top.align-self-center {	
		align-self: auto !important;
		padding: 0;
	}
	.navbar.header-fixed-top {
	    padding-top: 9px;
		padding-bottom: 8px;
	}
	.navbar.header-fixed-top .nav .themes-header-top {
		padding: 0 0 1rem;
	}
}

@media (min-width: 992px) {
	.navbar-brand {
		padding-top: 1.750rem;
		padding-bottom: 1.750rem;
	}
	.site-branding-text {
		padding-top: 1.5rem;
		padding-bottom: 1.5rem;
	}
	.navbar.header-fixed-top .navbar-brand {
		padding-top: 0.900rem;
		padding-bottom: 0.900rem;
	}
	.navbar.header-fixed-top .sticky-navbar-brand {
		padding-top: 0.900rem;
		padding-bottom: 0.900rem;
		margin-right: 1rem;
	}
	.navbar { 
		padding-top: 0;
		padding-bottom: 0;
	}
	.navbar .nav .menu-item .nav-link {
		padding: 2.220rem 1rem;
	}
	.navbar .nav .dropdown-menu {
		padding: 0;
		top: 99px !important;
	}
	.navbar.header-fixed-top .nav .dropdown-menu {
		top: 73px !important;
	}
	.navbar .nav .dropdown-menu { 
		background-color: #fff; 
		box-shadow: 0 4px 7px 0 rgba(0, 0, 0, 0.12), 0 3px 12px 0 rgba(0, 0, 0, 0.12); 
	}
	.navbar .nav .dropdown-item {
		color: #000;
		border-bottom: 1px solid rgb(242, 242, 242);
		padding: 7px 25px;
	} 
	.navbar .nav .dropdown-item:focus, 
	.navbar .nav .dropdown-item:hover {
		background-color: transparent;
	}
	.navbar .nav .dropdown-menu ul.dropdown-menu {
        top: auto !important;
    }
    .navbar.header-fixed-top .nav .dropdown-menu ul.dropdown-menu {
        top: auto !important;
    }	
}

/*End Css*/

.navbar-nav.sm-collapsible .sub-arrow {
	position: absolute;
	top: 50%;
	right: 0;
	margin: -0.7em 0.5em 0 0;
	border: 1px solid rgba(0, 0, 0, .1);
	border-radius: .25rem;
	padding: 0;
	width: 2em;
	height: 1.4em;
	font-size: 1.25rem;
	line-height: 1.2em;
	text-align: center;
}
.navbar-nav.sm-collapsible .sub-arrow::before {
	content: '+';
}
.navbar-nav.sm-collapsible .show > a > .sub-arrow::before {
	content: '-';
}
.navbar-dark .navbar-nav.sm-collapsible .nav-link .sub-arrow {
	border-color: rgba(255, 255, 255, .1);
}
/* make sure there's room for the carets */
.navbar-nav.sm-collapsible .has-submenu {
	padding-right: 3em;
}
/* keep the carets properly positioned */
.navbar-nav.sm-collapsible .nav-link,
.navbar-nav.sm-collapsible .dropdown-item {
	position: relative;
}

/* Nav carets in expanded mode */
.navbar-nav:not(.sm-collapsible) .nav-link .sub-arrow {
	display: inline-block;
	width: 0;
	height: 0;
	margin-left: .255em;
	vertical-align: .255em;
	border-top: .3em solid;
	border-right: .3em solid transparent;
	border-left: .3em solid transparent;
}
/* point the arrows up for .fixed-bottom navbars */
.fixed-bottom .navbar-nav:not(.sm-collapsible) .nav-link .sub-arrow,
.fixed-bottom .navbar-nav:not(.sm-collapsible):not([data-sm-skip]) .dropdown-toggle::after {
	border-top: 0;
	border-bottom: .3em solid;
}

/* Dropdown carets in expanded mode */
.navbar-nav:not(.sm-collapsible) .dropdown-item .sub-arrow,
.navbar-nav:not(.sm-collapsible):not([data-sm-skip]) .dropdown-menu .dropdown-toggle::after {
	position: absolute;
	top: 50%;
	right: 0;
	width: 0;
	height: 0;
	margin-top: -.3em;
	margin-right: 1em;
	border-top: .3em solid transparent;
	border-bottom: .3em solid transparent;
	border-left: .3em solid;
}
/* make sure there's room for the carets */
.navbar-nav:not(.sm-collapsible) .dropdown-item.has-submenu {
	padding-right: 2em;
}


/* Scrolling arrows for tall menus */
.navbar-nav .scroll-up,
.navbar-nav .scroll-down {
	position: absolute;
	display: none;
	visibility: hidden;
	height: 20px;
	overflow: hidden;
	text-align: center;
}
.navbar-nav .scroll-up-arrow,
.navbar-nav .scroll-down-arrow {
	position: absolute;
	top: -2px;
	left: 50%;
	margin-left: -8px;
	width: 0;
	height: 0;
	overflow: hidden;
	border-top: 7px solid transparent;
	border-right: 7px solid transparent;
	border-bottom: 7px solid;
	border-left: 7px solid transparent;
}
.navbar-nav .scroll-down-arrow {
	top: 6px;
	border-top: 7px solid;
	border-right: 7px solid transparent;
	border-bottom: 7px solid transparent;
	border-left: 7px solid transparent;
}

/* Add some spacing for 2+ level sub menus in collapsible mode */
.navbar-nav.sm-collapsible .dropdown-menu .dropdown-menu {
	margin: .5em;
}

/* Fix SmartMenus sub menus auto width (subMenusMinWidth/subMenusMaxWidth options) */
.navbar-nav:not([data-sm-skip]) .dropdown-item {
	white-space: normal;
}
.navbar-nav:not(.sm-collapsible) .sm-nowrap > li > .dropdown-item {
	white-space: nowrap;
	
}

/*Add Menu*/
.navbar .nav .menu-item .nav-link.add-menu {
	text-transform: capitalize;
    background-color: #ffffff;
    padding: 0.313rem 1.3rem;
	margin: 1.75rem 0;
    text-align: center;
    border-radius: 0px;
}
.navbar.navbar-header-wrap.header-fixed-top .nav .menu-item .nav-link.add-menu {
	margin: 1rem 0;
}
.navbar .nav .menu-item .nav-link.add-menu:hover, 
.navbar .nav .menu-item .nav-link.add-menu:focus {
	color: #fff;
}
.navbar .nav .menu-item .nav-link.add-menu:before {
	font-family: "FontAwesome";
	content: "\f055";
	padding-right: 0.438rem;
}